pstar
=====

Tar Archiv tool Written in Python, supported on Linux and Windows

Usage
=====

cf
--

.. code-block:: bash

   pstar -cf <name>.tar <files>

cJf
---

.. code-block:: bash

   pstar -cJf <name>.tar.xz <files>

czf
---

.. code-block:: bash

   pstar -czf <name>.tar.gz <file>

xf
--

.. code-block:: bash

   pstar -xf <name>.tar

xvf
---

.. code-block:: bash

   pstar -xvf <name>.tar.xz

xzf
---

.. code-block:: bash

   pstar -xzf <name>.tar.gz
